@@ -47,25 +47,25 @@ var NAVTREEINDEX =
 "alloc_8h.html",
 "group__pw__data__loop.html#ga31fb97e55669c3673f4912ff08fc25f5",
 "group__pw__impl__port.html#ga5682619e17eb12d4bd4c7d70e985e08c",
-"group__pw__loop.html#ga6edef1937eb5fc176a6a36485eebf8ad",
-"group__pw__properties.html#ga88e954267fa14f49b4b7b924a0022304",
-"group__pw__session__manager.html#gacfc215ae22e6a99a5ff459f928d24daa",
-"group__spa__buffer.html#gaebb70d9cbd7c2ae9cd782216dbb51fb6",
-"group__spa__graph.html#ga3707f5819de7baf600d84a452971e0e9",
-"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63dae9487966c0b9cefeba778422c483df64",
-"group__spa__node.html#gga12aed5ed2a6ecb69734aa3eb7da4056ba38a0f9a63830ad342b24e09879621165",
-"group__spa__param.html#gad217270e27de71f254d3d7c3d4fcf4f0",
-"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbcad91fa4ee2ae74a39b3e8d738d692fd30",
-"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa5af6aa53a0bcdbd9313f8dd5d38ad706",
-"group__spa__pod.html#ga4c35e58037a9afea52cb6697bb890eba",
-"group__spa__system.html#ga2dcb97fa874ae364a19ce37d7f7ed90f",
-"page_client_impl.html#sec_page_client_impl_credentials",
-"route-types_8h.html",
-"structpw__endpoint__stream__methods.html#ab7b9c94de60336876dac12fbd671e8cb",
-"structpw__port__methods.html#a3c19aedb668ea1a71bc12f89b106d94a",
-"structspa__buffer__alloc__info.html",
-"structspa__io__segment__video.html#aefffdac704f6aa878542c37d5cc7accb",
-"structspa__pod__pointer__body.html#a2c444fd3eda0725199a91713c7b5676c"
+"group__pw__loop.html#ga5e937f4e92704c5b7924c07605d06318",
+"group__pw__properties.html#ga7bedc63c78dfe152e866dc518424f299",
+"group__pw__session__manager.html#gacf65a96b2b6cb1f16af259bc667518bd",
+"group__spa__buffer.html#gaeaf6a23eedc8287e462151c68cf392d8",
+"group__spa__graph.html#ga35411dc23f99354fb70e3c298426da7a",
+"group__spa__log.html#gga08076f4c659566e0c3f1a8dee549b63da9b78d95227c88fe557d5836fef32f114",
+"group__spa__node.html#gga12aed5ed2a6ecb69734aa3eb7da4056ba2dca266818c242b100929746f01af7ff",
+"group__spa__param.html#gad0293e0aafd77aba1e85b110450c3f67",
+"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbcad275daa367818990fbd7869290282ace",
+"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa5916c4975331ef07c3a0b1a7c54701f5",
+"group__spa__pod.html#ga4af85c705eae32732d08dd70375e6720",
+"group__spa__system.html#ga282e1c96dc3c64fe48b01b93257191a3",
+"page_client_impl.html",
+"ringbuffer_8h.html",
+"structpw__endpoint__stream__methods.html#a795f1ab22b0899bc18142419723e369b",
+"structpw__port__info.html#ae58ded9d9277c0f93862d58026faf4e2",
+"structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e",
+"structspa__io__segment__video.html#add60a69b800c7177da7a687fc47984db",
+"structspa__pod__pointer.html#a1aefb7792b75ea7882c273abf8a2edce"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
