@@ -1,5 +1,8 @@
 var NAVTREEINDEX19 =
 {
+"structspa__buffer.html#a9705c915e89400eaa96a1fe84209e53e":[8,6,1,7,2],
+"structspa__buffer.html#ad4c72bfda8875b33b7316af4bafb9560":[8,6,1,7,3],
+"structspa__buffer.html#adbf5510ef0707e22b19980c84b61a073":[8,6,1,7,1],
 "structspa__buffer__alloc__info.html":[8,6,1,4],
 "structspa__buffer__alloc__info.html#a2598f62c920f42fd1ea6547968c0e2a6":[8,6,1,4,11],
 "structspa__buffer__alloc__info.html#a30233569ad362f458d9e1344d0b5a58c":[8,6,1,4,10],
@@ -246,8 +249,5 @@ var NAVTREEINDEX19 =
 "structspa__io__segment__video.html#a500d2d64d490ad483be879cb40b799b4":[8,6,6,14,2],
 "structspa__io__segment__video.html#a9c45645d7e6aa9aea4508336dd87d17d":[8,6,6,14,7],
 "structspa__io__segment__video.html#abb72f2853693bb3cfad27520b41f3248":[8,6,6,14,0],
-"structspa__io__segment__video.html#ad9a1cecce33ac8e1c02532188fe51b5f":[8,6,6,14,3],
-"structspa__io__segment__video.html#add60a69b800c7177da7a687fc47984db":[8,6,6,14,4],
-"structspa__io__segment__video.html#ae03652e1ab2e76a1a03a63d7bd0fcc99":[8,6,6,14,8],
-"structspa__io__segment__video.html#ae1cc1d15b524665254cff4c3d5daeceb":[8,6,6,14,6]
+"structspa__io__segment__video.html#ad9a1cecce33ac8e1c02532188fe51b5f":[8,6,6,14,3]
 };
